@@ -1,4 +1,9 @@
-from django.conf.urls.defaults import patterns, include, url
+try: 
+    from django.conf.urls import patterns, url 
+except ImportError: 
+    # for Django version less then 1.4
+    from django.conf.urls.defaults import patterns, url
+
 
 urlpatterns = patterns('sidebar.views',
     url(r'^sidebar/$', 'ajax_load_widgets', name='load_sidebar'),
